@@ -1174,6 +1174,11 @@ run_digital (screen, window)
         else
           target_frames [n] = base_frames [time_digits [n]];
 
+      if (twelve_hour_time && target_frames [0] && time_digits [0] == 0)
+	{
+	  target_frames [0] = clear_frame;
+	  time_digits [0] = -1;
+	}
       if (time_digits [0] < 0 && last_time_digits [0] < 0)
         target_frames [0] = 0;
       if (last_time_digits [0] == -2) /* evil hack for 12<->24 mode toggle */
