@@ -1,4 +1,4 @@
-/* xscreensaver, Copyright (c) 1993, 1994, 1995, 1996, 1997
+/* xscreensaver, Copyright (c) 1993, 1994, 1995, 1996, 1997, 1999
  *  by Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -35,6 +35,10 @@
 # endif
 #endif
 
+#if defined(VMS) && ( __VMS_VER < 70000000)
+char *strdup(const char *s1);
+#endif
+
 #ifndef isupper
 # define isupper(c)  ((c) >= 'A' && (c) <= 'Z')
 #endif
