@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998
+ * Copyright (c) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999
  *  Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -483,7 +483,7 @@ hack_version P((void))
   *dst2 = 0;
 }
 
-#ifdef VMS
+#if defined(VMS) && (__VMS_VER < 70000000)
 /* this isn't right, but it's good enough (only returns 1 or 0) */
 int
 strcasecmp (s1, s2)
@@ -500,4 +500,12 @@ strcasecmp (s1, s2)
       return 1;
   return 0;
 }
-#endif /* VMS */
+
+char *
+strdup (const char* s1)
+{
+  char *s2 = (char*) malloc (strlen (s1) + 1);
+  if (s2) strcpy (s2, s1);
+  return s2;
+}
+#endif /* VMS && __VMS_VER < 70000000 */
