@@ -1,5 +1,5 @@
 /* xdaliclock - a melting digital clock
- * Copyright (c) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998
+ * Copyright (c) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999
  *  Jamie Zawinski <jwz@jwz.org>
  *
  * Permission to use, copy, modify, distribute, and sell this software and its
@@ -21,7 +21,10 @@
 #ifdef VMS
 # include <descrip.h>
 # define R_OK 4
-int strcasecmp(char *s1, char *s2);
+# if __VMS_VER < 70000000
+  int strcasecmp(char *s1, char *s2);
+  char *strdup(const char *s1);
+# endif
 #endif
 
 #ifndef isupper
